# arpes.utilities.collections module

**arpes.utilities.collections.deep\_equals(a, b)**

**arpes.utilities.collections.deep\_update(destination, source)**

> Doesn’t clobber keys further down trees like doing a shallow update
> would. Instead recurse down from the root and update as appropriate.
> :param destination: :param source: :return:
